@@ -31,12 +31,11 @@ dqrng::rng64_t rng = dqrng::generator();
 // [[Rcpp::export(rng = false)]]
 void dqset_seed(const uint32_t seed) {
   uint64_t seed2  = 1664525 * seed + 1013904223;
-  uint64_t _seed = seed || (seed2 << 32);
+  uint64_t _seed = seed | (seed2 << 32);
   rng->seed(_seed);
 }
 
-//' @name dqrng
-//' @rdname dqrng
+//' @rdname dqrng-functions
 //' @export
 // [[Rcpp::export(rng = false)]]
 void dqRNGkind(std::string kind, const std::string& normal_kind = "ignored") {
@@ -58,7 +57,7 @@ void dqRNGkind(std::string kind, const std::string& normal_kind = "ignored") {
   }
 }
 
-//' @rdname dqrng
+//' @rdname dqrng-functions
 //' @export
 // [[Rcpp::export(rng = false)]]
 Rcpp::NumericVector dqrunif(size_t n, double min = 0.0, double max = 1.0) {
@@ -69,7 +68,7 @@ Rcpp::NumericVector dqrunif(size_t n, double min = 0.0, double max = 1.0) {
   return dqrng::generate<dqrng::uniform_distribution, Rcpp::NumericVector>(n, rng, dist);
 }
 
-//' @rdname dqrng
+//' @rdname dqrng-functions
 //' @export
 // [[Rcpp::export(rng = false)]]
 Rcpp::NumericVector dqrnorm(size_t n, double mean = 0.0, double sd = 1.0) {
@@ -77,7 +76,7 @@ Rcpp::NumericVector dqrnorm(size_t n, double mean = 0.0, double sd = 1.0) {
   return dqrng::generate<dqrng::normal_distribution, Rcpp::NumericVector>(n, rng, dist);
 }
 
-//' @rdname dqrng
+//' @rdname dqrng-functions
 //' @export
 // [[Rcpp::export(rng = false)]]
 Rcpp::NumericVector dqrexp(size_t n, double rate = 1.0) {
